/*
 * Copyright Bigeon Emmanuel (2014)
 *
 * emmanuel@bigeon.fr
 *
 * This software is a computer program whose purpose is to
 * provide a generic framework for console applications.
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 */
/**
 * gclc:fr.bigeon.gclc.proc.ProcessList.java
 * Created on: May 10, 2017
 */
package fr.bigeon.gclc.proc;

import java.io.IOException;
import java.text.MessageFormat;
import java.util.ArrayList;
import java.util.Collections;

import fr.bigeon.gclc.command.Command;
import fr.bigeon.gclc.exception.CommandRunException;
import fr.bigeon.gclc.exception.CommandRunExceptionType;
import fr.bigeon.gclc.manager.ConsoleManager;

/** A command to list current processes
 *
 * @author Emmanuel Bigeon */
public class ProcessList extends Command {
    /** The process pool */
    private final TaskPool pool;

    /** the interaction object */
    private final ConsoleManager manager;

    /** @param name the command name
     * @param pool the pool
     * @param manager the console manager */
    public ProcessList(String name, TaskPool pool,
            ConsoleManager manager) {
        super(name);
        this.pool = pool;
        this.manager = manager;
    }

    /* (non-Javadoc)
     * @see fr.bigeon.gclc.command.ICommand#execute(java.lang.String[])
     */
    @Override
    public void execute(String... args) throws CommandRunException {
        ArrayList<String> pids = new ArrayList<>(pool.getPIDs());
        Collections.sort(pids);
        for (String string : pids) {
            try {
                manager.println(
                        MessageFormat.format("{0}\t{1}", string, //$NON-NLS-1$
                                pool.get(string).getName()));
            } catch (IOException e) {
                throw new CommandRunException(
                        CommandRunExceptionType.INTERACTION,
                        "Unable to communicate with user", e, this); //$NON-NLS-1$
            }
        }
        
    }

    /* (non-Javadoc)
     * @see fr.bigeon.gclc.command.ICommand#tip()
     */
    @SuppressWarnings("nls")
    @Override
    public String tip() {
        return "List all processes";
    }

}
